# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TokenArgs', 'Token']

@pulumi.input_type
class TokenArgs:
    def __init__(__self__, *,
                 account_id: pulumi.Input[_builtins.str],
                 apikey_id: pulumi.Input[_builtins.str],
                 apikey_type: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 parent_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 encoded_password: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 scheduled_expire_time: Optional[pulumi.Input[_builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 valid: Optional[pulumi.Input[_builtins.bool]] = None,
                 valid_from: Optional[pulumi.Input[_builtins.int]] = None,
                 valid_to: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a Token resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.str] apikey_id: Identifier of the API Key
        :param pulumi.Input[_builtins.str] apikey_type: Type of the API Key
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] parent_id: Parent Entity Identifier of the API Key
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] email: Email Id of the user who created the Token
        :param pulumi.Input[_builtins.str] encoded_password: Encoded password of the Token
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.int] scheduled_expire_time: Scheduled expiry time in milliseconds
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] username: Name of the user who created the Token
        :param pulumi.Input[_builtins.bool] valid: Boolean value to indicate if Token is valid or not.
        :param pulumi.Input[_builtins.int] valid_from: This is the time from which the Token is valid. The time is in milliseconds
        :param pulumi.Input[_builtins.int] valid_to: This is the time till which the Token is valid. The time is in milliseconds
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "apikey_id", apikey_id)
        pulumi.set(__self__, "apikey_type", apikey_type)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "parent_id", parent_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if encoded_password is not None:
            pulumi.set(__self__, "encoded_password", encoded_password)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if scheduled_expire_time is not None:
            pulumi.set(__self__, "scheduled_expire_time", scheduled_expire_time)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if valid is not None:
            pulumi.set(__self__, "valid", valid)
        if valid_from is not None:
            pulumi.set(__self__, "valid_from", valid_from)
        if valid_to is not None:
            pulumi.set(__self__, "valid_to", valid_to)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Input[_builtins.str]:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="apikeyId")
    def apikey_id(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the API Key
        """
        return pulumi.get(self, "apikey_id")

    @apikey_id.setter
    def apikey_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "apikey_id", value)

    @_builtins.property
    @pulumi.getter(name="apikeyType")
    def apikey_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of the API Key
        """
        return pulumi.get(self, "apikey_type")

    @apikey_type.setter
    def apikey_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "apikey_type", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> pulumi.Input[_builtins.str]:
        """
        Parent Entity Identifier of the API Key
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Email Id of the user who created the Token
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter(name="encodedPassword")
    def encoded_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Encoded password of the Token
        """
        return pulumi.get(self, "encoded_password")

    @encoded_password.setter
    def encoded_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "encoded_password", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="scheduledExpireTime")
    def scheduled_expire_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Scheduled expiry time in milliseconds
        """
        return pulumi.get(self, "scheduled_expire_time")

    @scheduled_expire_time.setter
    def scheduled_expire_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "scheduled_expire_time", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the user who created the Token
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)

    @_builtins.property
    @pulumi.getter
    def valid(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean value to indicate if Token is valid or not.
        """
        return pulumi.get(self, "valid")

    @valid.setter
    def valid(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "valid", value)

    @_builtins.property
    @pulumi.getter(name="validFrom")
    def valid_from(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        This is the time from which the Token is valid. The time is in milliseconds
        """
        return pulumi.get(self, "valid_from")

    @valid_from.setter
    def valid_from(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "valid_from", value)

    @_builtins.property
    @pulumi.getter(name="validTo")
    def valid_to(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        This is the time till which the Token is valid. The time is in milliseconds
        """
        return pulumi.get(self, "valid_to")

    @valid_to.setter
    def valid_to(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "valid_to", value)


@pulumi.input_type
class _TokenState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 apikey_id: Optional[pulumi.Input[_builtins.str]] = None,
                 apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 encoded_password: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 scheduled_expire_time: Optional[pulumi.Input[_builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 valid: Optional[pulumi.Input[_builtins.bool]] = None,
                 valid_from: Optional[pulumi.Input[_builtins.int]] = None,
                 valid_to: Optional[pulumi.Input[_builtins.int]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Token resources.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.str] apikey_id: Identifier of the API Key
        :param pulumi.Input[_builtins.str] apikey_type: Type of the API Key
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] email: Email Id of the user who created the Token
        :param pulumi.Input[_builtins.str] encoded_password: Encoded password of the Token
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] parent_id: Parent Entity Identifier of the API Key
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.int] scheduled_expire_time: Scheduled expiry time in milliseconds
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] username: Name of the user who created the Token
        :param pulumi.Input[_builtins.bool] valid: Boolean value to indicate if Token is valid or not.
        :param pulumi.Input[_builtins.int] valid_from: This is the time from which the Token is valid. The time is in milliseconds
        :param pulumi.Input[_builtins.int] valid_to: This is the time till which the Token is valid. The time is in milliseconds
        :param pulumi.Input[_builtins.str] value: Value of the Token
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if apikey_id is not None:
            pulumi.set(__self__, "apikey_id", apikey_id)
        if apikey_type is not None:
            pulumi.set(__self__, "apikey_type", apikey_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if encoded_password is not None:
            pulumi.set(__self__, "encoded_password", encoded_password)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if parent_id is not None:
            pulumi.set(__self__, "parent_id", parent_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if scheduled_expire_time is not None:
            pulumi.set(__self__, "scheduled_expire_time", scheduled_expire_time)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if valid is not None:
            pulumi.set(__self__, "valid", valid)
        if valid_from is not None:
            pulumi.set(__self__, "valid_from", valid_from)
        if valid_to is not None:
            pulumi.set(__self__, "valid_to", valid_to)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="apikeyId")
    def apikey_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the API Key
        """
        return pulumi.get(self, "apikey_id")

    @apikey_id.setter
    def apikey_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "apikey_id", value)

    @_builtins.property
    @pulumi.getter(name="apikeyType")
    def apikey_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the API Key
        """
        return pulumi.get(self, "apikey_type")

    @apikey_type.setter
    def apikey_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "apikey_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Email Id of the user who created the Token
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter(name="encodedPassword")
    def encoded_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Encoded password of the Token
        """
        return pulumi.get(self, "encoded_password")

    @encoded_password.setter
    def encoded_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "encoded_password", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Parent Entity Identifier of the API Key
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="scheduledExpireTime")
    def scheduled_expire_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Scheduled expiry time in milliseconds
        """
        return pulumi.get(self, "scheduled_expire_time")

    @scheduled_expire_time.setter
    def scheduled_expire_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "scheduled_expire_time", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the user who created the Token
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)

    @_builtins.property
    @pulumi.getter
    def valid(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean value to indicate if Token is valid or not.
        """
        return pulumi.get(self, "valid")

    @valid.setter
    def valid(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "valid", value)

    @_builtins.property
    @pulumi.getter(name="validFrom")
    def valid_from(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        This is the time from which the Token is valid. The time is in milliseconds
        """
        return pulumi.get(self, "valid_from")

    @valid_from.setter
    def valid_from(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "valid_from", value)

    @_builtins.property
    @pulumi.getter(name="validTo")
    def valid_to(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        This is the time till which the Token is valid. The time is in milliseconds
        """
        return pulumi.get(self, "valid_to")

    @valid_to.setter
    def valid_to(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "valid_to", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Value of the Token
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


@pulumi.type_token("harness:platform/token:Token")
class Token(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 apikey_id: Optional[pulumi.Input[_builtins.str]] = None,
                 apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 encoded_password: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 scheduled_expire_time: Optional[pulumi.Input[_builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 valid: Optional[pulumi.Input[_builtins.bool]] = None,
                 valid_from: Optional[pulumi.Input[_builtins.int]] = None,
                 valid_to: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Resource for creating tokens.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level token

        ```sh
        $ pulumi import harness:platform/token:Token harness_platform_token <parent_id>/<apikey_id>/<apikey_type>/<token_id>
        ```

        Import org level token

        ```sh
        $ pulumi import harness:platform/token:Token harness_platform_token <org_id>/<parent_id>/<apikey_id>/<apikey_type>/<token_id>
        ```

        Import project level token

        ```sh
        $ pulumi import harness:platform/token:Token harness_platform_token <org_id>/<project_id>/<parent_id>/<apikey_id>/<apikey_type>/<token_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.str] apikey_id: Identifier of the API Key
        :param pulumi.Input[_builtins.str] apikey_type: Type of the API Key
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] email: Email Id of the user who created the Token
        :param pulumi.Input[_builtins.str] encoded_password: Encoded password of the Token
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] parent_id: Parent Entity Identifier of the API Key
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.int] scheduled_expire_time: Scheduled expiry time in milliseconds
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] username: Name of the user who created the Token
        :param pulumi.Input[_builtins.bool] valid: Boolean value to indicate if Token is valid or not.
        :param pulumi.Input[_builtins.int] valid_from: This is the time from which the Token is valid. The time is in milliseconds
        :param pulumi.Input[_builtins.int] valid_to: This is the time till which the Token is valid. The time is in milliseconds
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating tokens.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level token

        ```sh
        $ pulumi import harness:platform/token:Token harness_platform_token <parent_id>/<apikey_id>/<apikey_type>/<token_id>
        ```

        Import org level token

        ```sh
        $ pulumi import harness:platform/token:Token harness_platform_token <org_id>/<parent_id>/<apikey_id>/<apikey_type>/<token_id>
        ```

        Import project level token

        ```sh
        $ pulumi import harness:platform/token:Token harness_platform_token <org_id>/<project_id>/<parent_id>/<apikey_id>/<apikey_type>/<token_id>
        ```

        :param str resource_name: The name of the resource.
        :param TokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 apikey_id: Optional[pulumi.Input[_builtins.str]] = None,
                 apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 encoded_password: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 scheduled_expire_time: Optional[pulumi.Input[_builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 valid: Optional[pulumi.Input[_builtins.bool]] = None,
                 valid_from: Optional[pulumi.Input[_builtins.int]] = None,
                 valid_to: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TokenArgs.__new__(TokenArgs)

            if account_id is None and not opts.urn:
                raise TypeError("Missing required property 'account_id'")
            __props__.__dict__["account_id"] = account_id
            if apikey_id is None and not opts.urn:
                raise TypeError("Missing required property 'apikey_id'")
            __props__.__dict__["apikey_id"] = apikey_id
            if apikey_type is None and not opts.urn:
                raise TypeError("Missing required property 'apikey_type'")
            __props__.__dict__["apikey_type"] = apikey_type
            __props__.__dict__["description"] = description
            __props__.__dict__["email"] = email
            __props__.__dict__["encoded_password"] = encoded_password
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            if parent_id is None and not opts.urn:
                raise TypeError("Missing required property 'parent_id'")
            __props__.__dict__["parent_id"] = parent_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["scheduled_expire_time"] = scheduled_expire_time
            __props__.__dict__["tags"] = tags
            __props__.__dict__["username"] = username
            __props__.__dict__["valid"] = valid
            __props__.__dict__["valid_from"] = valid_from
            __props__.__dict__["valid_to"] = valid_to
            __props__.__dict__["value"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["value"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Token, __self__).__init__(
            'harness:platform/token:Token',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            apikey_id: Optional[pulumi.Input[_builtins.str]] = None,
            apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            email: Optional[pulumi.Input[_builtins.str]] = None,
            encoded_password: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            parent_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            scheduled_expire_time: Optional[pulumi.Input[_builtins.int]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            username: Optional[pulumi.Input[_builtins.str]] = None,
            valid: Optional[pulumi.Input[_builtins.bool]] = None,
            valid_from: Optional[pulumi.Input[_builtins.int]] = None,
            valid_to: Optional[pulumi.Input[_builtins.int]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None) -> 'Token':
        """
        Get an existing Token resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.str] apikey_id: Identifier of the API Key
        :param pulumi.Input[_builtins.str] apikey_type: Type of the API Key
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] email: Email Id of the user who created the Token
        :param pulumi.Input[_builtins.str] encoded_password: Encoded password of the Token
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] parent_id: Parent Entity Identifier of the API Key
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.int] scheduled_expire_time: Scheduled expiry time in milliseconds
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] username: Name of the user who created the Token
        :param pulumi.Input[_builtins.bool] valid: Boolean value to indicate if Token is valid or not.
        :param pulumi.Input[_builtins.int] valid_from: This is the time from which the Token is valid. The time is in milliseconds
        :param pulumi.Input[_builtins.int] valid_to: This is the time till which the Token is valid. The time is in milliseconds
        :param pulumi.Input[_builtins.str] value: Value of the Token
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TokenState.__new__(_TokenState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["apikey_id"] = apikey_id
        __props__.__dict__["apikey_type"] = apikey_type
        __props__.__dict__["description"] = description
        __props__.__dict__["email"] = email
        __props__.__dict__["encoded_password"] = encoded_password
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["parent_id"] = parent_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["scheduled_expire_time"] = scheduled_expire_time
        __props__.__dict__["tags"] = tags
        __props__.__dict__["username"] = username
        __props__.__dict__["valid"] = valid
        __props__.__dict__["valid_from"] = valid_from
        __props__.__dict__["valid_to"] = valid_to
        __props__.__dict__["value"] = value
        return Token(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="apikeyId")
    def apikey_id(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the API Key
        """
        return pulumi.get(self, "apikey_id")

    @_builtins.property
    @pulumi.getter(name="apikeyType")
    def apikey_type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of the API Key
        """
        return pulumi.get(self, "apikey_type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Email Id of the user who created the Token
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter(name="encodedPassword")
    def encoded_password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Encoded password of the Token
        """
        return pulumi.get(self, "encoded_password")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> pulumi.Output[_builtins.str]:
        """
        Parent Entity Identifier of the API Key
        """
        return pulumi.get(self, "parent_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="scheduledExpireTime")
    def scheduled_expire_time(self) -> pulumi.Output[_builtins.int]:
        """
        Scheduled expiry time in milliseconds
        """
        return pulumi.get(self, "scheduled_expire_time")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the user who created the Token
        """
        return pulumi.get(self, "username")

    @_builtins.property
    @pulumi.getter
    def valid(self) -> pulumi.Output[_builtins.bool]:
        """
        Boolean value to indicate if Token is valid or not.
        """
        return pulumi.get(self, "valid")

    @_builtins.property
    @pulumi.getter(name="validFrom")
    def valid_from(self) -> pulumi.Output[_builtins.int]:
        """
        This is the time from which the Token is valid. The time is in milliseconds
        """
        return pulumi.get(self, "valid_from")

    @_builtins.property
    @pulumi.getter(name="validTo")
    def valid_to(self) -> pulumi.Output[_builtins.int]:
        """
        This is the time till which the Token is valid. The time is in milliseconds
        """
        return pulumi.get(self, "valid_to")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[_builtins.str]:
        """
        Value of the Token
        """
        return pulumi.get(self, "value")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IacmDefaultPipelineArgs', 'IacmDefaultPipeline']

@pulumi.input_type
class IacmDefaultPipelineArgs:
    def __init__(__self__, *,
                 operation: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 pipeline: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 provisioner_type: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a IacmDefaultPipeline resource.
        :param pulumi.Input[_builtins.str] operation: The operation associated with this default.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the organization the default pipelines resides in.
        :param pulumi.Input[_builtins.str] pipeline: The pipeline associated with this default.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the project the default pipelines resides in.
        :param pulumi.Input[_builtins.str] provisioner_type: The provisioner associated with this default.
        """
        pulumi.set(__self__, "operation", operation)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "pipeline", pipeline)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "provisioner_type", provisioner_type)

    @_builtins.property
    @pulumi.getter
    def operation(self) -> pulumi.Input[_builtins.str]:
        """
        The operation associated with this default.
        """
        return pulumi.get(self, "operation")

    @operation.setter
    def operation(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "operation", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Organization identifier of the organization the default pipelines resides in.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def pipeline(self) -> pulumi.Input[_builtins.str]:
        """
        The pipeline associated with this default.
        """
        return pulumi.get(self, "pipeline")

    @pipeline.setter
    def pipeline(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pipeline", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Project identifier of the project the default pipelines resides in.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> pulumi.Input[_builtins.str]:
        """
        The provisioner associated with this default.
        """
        return pulumi.get(self, "provisioner_type")

    @provisioner_type.setter
    def provisioner_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "provisioner_type", value)


@pulumi.input_type
class _IacmDefaultPipelineState:
    def __init__(__self__, *,
                 operation: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IacmDefaultPipeline resources.
        :param pulumi.Input[_builtins.str] operation: The operation associated with this default.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the organization the default pipelines resides in.
        :param pulumi.Input[_builtins.str] pipeline: The pipeline associated with this default.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the project the default pipelines resides in.
        :param pulumi.Input[_builtins.str] provisioner_type: The provisioner associated with this default.
        """
        if operation is not None:
            pulumi.set(__self__, "operation", operation)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if pipeline is not None:
            pulumi.set(__self__, "pipeline", pipeline)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if provisioner_type is not None:
            pulumi.set(__self__, "provisioner_type", provisioner_type)

    @_builtins.property
    @pulumi.getter
    def operation(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The operation associated with this default.
        """
        return pulumi.get(self, "operation")

    @operation.setter
    def operation(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "operation", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization identifier of the organization the default pipelines resides in.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def pipeline(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The pipeline associated with this default.
        """
        return pulumi.get(self, "pipeline")

    @pipeline.setter
    def pipeline(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier of the project the default pipelines resides in.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The provisioner associated with this default.
        """
        return pulumi.get(self, "provisioner_type")

    @provisioner_type.setter
    def provisioner_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provisioner_type", value)


@pulumi.type_token("harness:platform/iacmDefaultPipeline:IacmDefaultPipeline")
class IacmDefaultPipeline(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 operation: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for managing IAC default pipelines

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.IacmDefaultPipeline("example",
            org_id=test["id"],
            project_id=test_harness_platform_project["id"],
            provisioner_type="terraform",
            operation="plan",
            pipeline="pipeline1")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] operation: The operation associated with this default.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the organization the default pipelines resides in.
        :param pulumi.Input[_builtins.str] pipeline: The pipeline associated with this default.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the project the default pipelines resides in.
        :param pulumi.Input[_builtins.str] provisioner_type: The provisioner associated with this default.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IacmDefaultPipelineArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing IAC default pipelines

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.IacmDefaultPipeline("example",
            org_id=test["id"],
            project_id=test_harness_platform_project["id"],
            provisioner_type="terraform",
            operation="plan",
            pipeline="pipeline1")
        ```

        :param str resource_name: The name of the resource.
        :param IacmDefaultPipelineArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IacmDefaultPipelineArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 operation: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IacmDefaultPipelineArgs.__new__(IacmDefaultPipelineArgs)

            if operation is None and not opts.urn:
                raise TypeError("Missing required property 'operation'")
            __props__.__dict__["operation"] = operation
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if pipeline is None and not opts.urn:
                raise TypeError("Missing required property 'pipeline'")
            __props__.__dict__["pipeline"] = pipeline
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if provisioner_type is None and not opts.urn:
                raise TypeError("Missing required property 'provisioner_type'")
            __props__.__dict__["provisioner_type"] = provisioner_type
        super(IacmDefaultPipeline, __self__).__init__(
            'harness:platform/iacmDefaultPipeline:IacmDefaultPipeline',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            operation: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            pipeline: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            provisioner_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'IacmDefaultPipeline':
        """
        Get an existing IacmDefaultPipeline resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] operation: The operation associated with this default.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the organization the default pipelines resides in.
        :param pulumi.Input[_builtins.str] pipeline: The pipeline associated with this default.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the project the default pipelines resides in.
        :param pulumi.Input[_builtins.str] provisioner_type: The provisioner associated with this default.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IacmDefaultPipelineState.__new__(_IacmDefaultPipelineState)

        __props__.__dict__["operation"] = operation
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["pipeline"] = pipeline
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["provisioner_type"] = provisioner_type
        return IacmDefaultPipeline(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def operation(self) -> pulumi.Output[_builtins.str]:
        """
        The operation associated with this default.
        """
        return pulumi.get(self, "operation")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Organization identifier of the organization the default pipelines resides in.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def pipeline(self) -> pulumi.Output[_builtins.str]:
        """
        The pipeline associated with this default.
        """
        return pulumi.get(self, "pipeline")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Project identifier of the project the default pipelines resides in.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> pulumi.Output[_builtins.str]:
        """
        The provisioner associated with this default.
        """
        return pulumi.get(self, "provisioner_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetImageRegistryResult',
    'AwaitableGetImageRegistryResult',
    'get_image_registry',
    'get_image_registry_output',
]

@pulumi.output_type
class GetImageRegistryResult:
    """
    A collection of values returned by getImageRegistry.
    """
    def __init__(__self__, check_override=None, created_at=None, custom_images=None, id=None, infra_id=None, is_default=None, is_override_allowed=None, is_private=None, org_id=None, override_blocked_by_scope=None, project_id=None, registry_account=None, registry_server=None, secret_name=None, updated_at=None, use_custom_images=None):
        if check_override and not isinstance(check_override, bool):
            raise TypeError("Expected argument 'check_override' to be a bool")
        pulumi.set(__self__, "check_override", check_override)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if custom_images and not isinstance(custom_images, list):
            raise TypeError("Expected argument 'custom_images' to be a list")
        pulumi.set(__self__, "custom_images", custom_images)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if infra_id and not isinstance(infra_id, str):
            raise TypeError("Expected argument 'infra_id' to be a str")
        pulumi.set(__self__, "infra_id", infra_id)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if is_override_allowed and not isinstance(is_override_allowed, bool):
            raise TypeError("Expected argument 'is_override_allowed' to be a bool")
        pulumi.set(__self__, "is_override_allowed", is_override_allowed)
        if is_private and not isinstance(is_private, bool):
            raise TypeError("Expected argument 'is_private' to be a bool")
        pulumi.set(__self__, "is_private", is_private)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if override_blocked_by_scope and not isinstance(override_blocked_by_scope, str):
            raise TypeError("Expected argument 'override_blocked_by_scope' to be a str")
        pulumi.set(__self__, "override_blocked_by_scope", override_blocked_by_scope)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if registry_account and not isinstance(registry_account, str):
            raise TypeError("Expected argument 'registry_account' to be a str")
        pulumi.set(__self__, "registry_account", registry_account)
        if registry_server and not isinstance(registry_server, str):
            raise TypeError("Expected argument 'registry_server' to be a str")
        pulumi.set(__self__, "registry_server", registry_server)
        if secret_name and not isinstance(secret_name, str):
            raise TypeError("Expected argument 'secret_name' to be a str")
        pulumi.set(__self__, "secret_name", secret_name)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if use_custom_images and not isinstance(use_custom_images, bool):
            raise TypeError("Expected argument 'use_custom_images' to be a bool")
        pulumi.set(__self__, "use_custom_images", use_custom_images)

    @_builtins.property
    @pulumi.getter(name="checkOverride")
    def check_override(self) -> Optional[_builtins.bool]:
        """
        Whether to check if override is allowed
        """
        return pulumi.get(self, "check_override")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Creation timestamp
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="customImages")
    def custom_images(self) -> Sequence['outputs.GetImageRegistryCustomImageResult']:
        """
        Custom images configuration
        """
        return pulumi.get(self, "custom_images")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="infraId")
    def infra_id(self) -> Optional[_builtins.str]:
        """
        The infrastructure ID to set up the image registry
        """
        return pulumi.get(self, "infra_id")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> _builtins.bool:
        """
        Whether this is the default registry
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter(name="isOverrideAllowed")
    def is_override_allowed(self) -> _builtins.bool:
        """
        Whether override is allowed for this registry
        """
        return pulumi.get(self, "is_override_allowed")

    @_builtins.property
    @pulumi.getter(name="isPrivate")
    def is_private(self) -> _builtins.bool:
        """
        Whether the registry is private
        """
        return pulumi.get(self, "is_private")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        The organization ID of the image registry
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="overrideBlockedByScope")
    def override_blocked_by_scope(self) -> _builtins.str:
        """
        Indicates if override is blocked by scope (only populated if check_override is true)
        """
        return pulumi.get(self, "override_blocked_by_scope")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        The project ID of the image registry
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="registryAccount")
    def registry_account(self) -> _builtins.str:
        """
        The registry account name
        """
        return pulumi.get(self, "registry_account")

    @_builtins.property
    @pulumi.getter(name="registryServer")
    def registry_server(self) -> _builtins.str:
        """
        The registry server URL
        """
        return pulumi.get(self, "registry_server")

    @_builtins.property
    @pulumi.getter(name="secretName")
    def secret_name(self) -> _builtins.str:
        """
        The name of the secret for authentication
        """
        return pulumi.get(self, "secret_name")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Last update timestamp
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="useCustomImages")
    def use_custom_images(self) -> _builtins.bool:
        """
        Whether custom images are used
        """
        return pulumi.get(self, "use_custom_images")


class AwaitableGetImageRegistryResult(GetImageRegistryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetImageRegistryResult(
            check_override=self.check_override,
            created_at=self.created_at,
            custom_images=self.custom_images,
            id=self.id,
            infra_id=self.infra_id,
            is_default=self.is_default,
            is_override_allowed=self.is_override_allowed,
            is_private=self.is_private,
            org_id=self.org_id,
            override_blocked_by_scope=self.override_blocked_by_scope,
            project_id=self.project_id,
            registry_account=self.registry_account,
            registry_server=self.registry_server,
            secret_name=self.secret_name,
            updated_at=self.updated_at,
            use_custom_images=self.use_custom_images)


def get_image_registry(check_override: Optional[_builtins.bool] = None,
                       infra_id: Optional[_builtins.str] = None,
                       org_id: Optional[_builtins.str] = None,
                       project_id: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetImageRegistryResult:
    """
    Data source for retrieving a Harness Chaos Image Registry and checking override status

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data source to verify the registry
    example = harness.chaos.get_image_registry(org_id="<org_id>",
        project_id="<project_id>")
    # Example of checking override status
    override_check = harness.chaos.get_image_registry(org_id="<org_id>",
        project_id="<project_id>",
        check_override=True)
    ```


    :param _builtins.bool check_override: Whether to check if override is allowed
    :param _builtins.str infra_id: The infrastructure ID to set up the image registry
    :param _builtins.str org_id: The organization ID of the image registry
    :param _builtins.str project_id: The project ID of the image registry
    """
    __args__ = dict()
    __args__['checkOverride'] = check_override
    __args__['infraId'] = infra_id
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:chaos/getImageRegistry:getImageRegistry', __args__, opts=opts, typ=GetImageRegistryResult).value

    return AwaitableGetImageRegistryResult(
        check_override=pulumi.get(__ret__, 'check_override'),
        created_at=pulumi.get(__ret__, 'created_at'),
        custom_images=pulumi.get(__ret__, 'custom_images'),
        id=pulumi.get(__ret__, 'id'),
        infra_id=pulumi.get(__ret__, 'infra_id'),
        is_default=pulumi.get(__ret__, 'is_default'),
        is_override_allowed=pulumi.get(__ret__, 'is_override_allowed'),
        is_private=pulumi.get(__ret__, 'is_private'),
        org_id=pulumi.get(__ret__, 'org_id'),
        override_blocked_by_scope=pulumi.get(__ret__, 'override_blocked_by_scope'),
        project_id=pulumi.get(__ret__, 'project_id'),
        registry_account=pulumi.get(__ret__, 'registry_account'),
        registry_server=pulumi.get(__ret__, 'registry_server'),
        secret_name=pulumi.get(__ret__, 'secret_name'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        use_custom_images=pulumi.get(__ret__, 'use_custom_images'))
def get_image_registry_output(check_override: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                              infra_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetImageRegistryResult]:
    """
    Data source for retrieving a Harness Chaos Image Registry and checking override status

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data source to verify the registry
    example = harness.chaos.get_image_registry(org_id="<org_id>",
        project_id="<project_id>")
    # Example of checking override status
    override_check = harness.chaos.get_image_registry(org_id="<org_id>",
        project_id="<project_id>",
        check_override=True)
    ```


    :param _builtins.bool check_override: Whether to check if override is allowed
    :param _builtins.str infra_id: The infrastructure ID to set up the image registry
    :param _builtins.str org_id: The organization ID of the image registry
    :param _builtins.str project_id: The project ID of the image registry
    """
    __args__ = dict()
    __args__['checkOverride'] = check_override
    __args__['infraId'] = infra_id
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:chaos/getImageRegistry:getImageRegistry', __args__, opts=opts, typ=GetImageRegistryResult)
    return __ret__.apply(lambda __response__: GetImageRegistryResult(
        check_override=pulumi.get(__response__, 'check_override'),
        created_at=pulumi.get(__response__, 'created_at'),
        custom_images=pulumi.get(__response__, 'custom_images'),
        id=pulumi.get(__response__, 'id'),
        infra_id=pulumi.get(__response__, 'infra_id'),
        is_default=pulumi.get(__response__, 'is_default'),
        is_override_allowed=pulumi.get(__response__, 'is_override_allowed'),
        is_private=pulumi.get(__response__, 'is_private'),
        org_id=pulumi.get(__response__, 'org_id'),
        override_blocked_by_scope=pulumi.get(__response__, 'override_blocked_by_scope'),
        project_id=pulumi.get(__response__, 'project_id'),
        registry_account=pulumi.get(__response__, 'registry_account'),
        registry_server=pulumi.get(__response__, 'registry_server'),
        secret_name=pulumi.get(__response__, 'secret_name'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        use_custom_images=pulumi.get(__response__, 'use_custom_images')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UserGroupPermissionsInitArgs', 'UserGroupPermissions']

@pulumi.input_type
class UserGroupPermissionsInitArgs:
    def __init__(__self__, *,
                 user_group_id: pulumi.Input[_builtins.str],
                 account_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 app_permissions: Optional[pulumi.Input['UserGroupPermissionsAppPermissionsArgs']] = None):
        """
        The set of arguments for constructing a UserGroupPermissions resource.
        :param pulumi.Input[_builtins.str] user_group_id: Unique identifier of the user group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] account_permissions: The account permissions of the user group. Valid options are ADMINISTER*OTHER*ACCOUNT*FUNCTIONS, CREATE*AND*DELETE*APPLICATION, CREATE*CUSTOM*DASHBOARDS, MANAGE*ALERT*NOTIFICATION*RULES, MANAGE*API*KEYS, MANAGE*APPLICATION*STACKS, MANAGE*AUTHENTICATION*SETTINGS, MANAGE*CLOUD*PROVIDERS, MANAGE*CONFIG*AS*CODE, MANAGE*CONNECTORS, MANAGE*CUSTOM*DASHBOARDS, MANAGE*DELEGATE*PROFILES, MANAGE*DELEGATES, MANAGE*DEPLOYMENT*FREEZES, MANAGE*IP*WHITELIST, MANAGE*PIPELINE*GOVERNANCE*STANDARDS, MANAGE*RESTRICTED*ACCESS, MANAGE*SECRET*MANAGERS, MANAGE*SECRETS, MANAGE*SSH*AND*WINRM, MANAGE*TAGS, MANAGE*TEMPLATE*LIBRARY, MANAGE*USER*AND*USER*GROUPS*AND*API*KEYS, MANAGE*USERS*AND*GROUPS, READ*USERS*AND*GROUPS, VIEW*AUDITS, VIEW*USER*AND*USER*GROUPS*AND*API_KEYS
        :param pulumi.Input['UserGroupPermissionsAppPermissionsArgs'] app_permissions: Application specific permissions
        """
        pulumi.set(__self__, "user_group_id", user_group_id)
        if account_permissions is not None:
            pulumi.set(__self__, "account_permissions", account_permissions)
        if app_permissions is not None:
            pulumi.set(__self__, "app_permissions", app_permissions)

    @_builtins.property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the user group.
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "user_group_id", value)

    @_builtins.property
    @pulumi.getter(name="accountPermissions")
    def account_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The account permissions of the user group. Valid options are ADMINISTER*OTHER*ACCOUNT*FUNCTIONS, CREATE*AND*DELETE*APPLICATION, CREATE*CUSTOM*DASHBOARDS, MANAGE*ALERT*NOTIFICATION*RULES, MANAGE*API*KEYS, MANAGE*APPLICATION*STACKS, MANAGE*AUTHENTICATION*SETTINGS, MANAGE*CLOUD*PROVIDERS, MANAGE*CONFIG*AS*CODE, MANAGE*CONNECTORS, MANAGE*CUSTOM*DASHBOARDS, MANAGE*DELEGATE*PROFILES, MANAGE*DELEGATES, MANAGE*DEPLOYMENT*FREEZES, MANAGE*IP*WHITELIST, MANAGE*PIPELINE*GOVERNANCE*STANDARDS, MANAGE*RESTRICTED*ACCESS, MANAGE*SECRET*MANAGERS, MANAGE*SECRETS, MANAGE*SSH*AND*WINRM, MANAGE*TAGS, MANAGE*TEMPLATE*LIBRARY, MANAGE*USER*AND*USER*GROUPS*AND*API*KEYS, MANAGE*USERS*AND*GROUPS, READ*USERS*AND*GROUPS, VIEW*AUDITS, VIEW*USER*AND*USER*GROUPS*AND*API_KEYS
        """
        return pulumi.get(self, "account_permissions")

    @account_permissions.setter
    def account_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "account_permissions", value)

    @_builtins.property
    @pulumi.getter(name="appPermissions")
    def app_permissions(self) -> Optional[pulumi.Input['UserGroupPermissionsAppPermissionsArgs']]:
        """
        Application specific permissions
        """
        return pulumi.get(self, "app_permissions")

    @app_permissions.setter
    def app_permissions(self, value: Optional[pulumi.Input['UserGroupPermissionsAppPermissionsArgs']]):
        pulumi.set(self, "app_permissions", value)


@pulumi.input_type
class _UserGroupPermissionsState:
    def __init__(__self__, *,
                 account_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 app_permissions: Optional[pulumi.Input['UserGroupPermissionsAppPermissionsArgs']] = None,
                 user_group_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering UserGroupPermissions resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] account_permissions: The account permissions of the user group. Valid options are ADMINISTER*OTHER*ACCOUNT*FUNCTIONS, CREATE*AND*DELETE*APPLICATION, CREATE*CUSTOM*DASHBOARDS, MANAGE*ALERT*NOTIFICATION*RULES, MANAGE*API*KEYS, MANAGE*APPLICATION*STACKS, MANAGE*AUTHENTICATION*SETTINGS, MANAGE*CLOUD*PROVIDERS, MANAGE*CONFIG*AS*CODE, MANAGE*CONNECTORS, MANAGE*CUSTOM*DASHBOARDS, MANAGE*DELEGATE*PROFILES, MANAGE*DELEGATES, MANAGE*DEPLOYMENT*FREEZES, MANAGE*IP*WHITELIST, MANAGE*PIPELINE*GOVERNANCE*STANDARDS, MANAGE*RESTRICTED*ACCESS, MANAGE*SECRET*MANAGERS, MANAGE*SECRETS, MANAGE*SSH*AND*WINRM, MANAGE*TAGS, MANAGE*TEMPLATE*LIBRARY, MANAGE*USER*AND*USER*GROUPS*AND*API*KEYS, MANAGE*USERS*AND*GROUPS, READ*USERS*AND*GROUPS, VIEW*AUDITS, VIEW*USER*AND*USER*GROUPS*AND*API_KEYS
        :param pulumi.Input['UserGroupPermissionsAppPermissionsArgs'] app_permissions: Application specific permissions
        :param pulumi.Input[_builtins.str] user_group_id: Unique identifier of the user group.
        """
        if account_permissions is not None:
            pulumi.set(__self__, "account_permissions", account_permissions)
        if app_permissions is not None:
            pulumi.set(__self__, "app_permissions", app_permissions)
        if user_group_id is not None:
            pulumi.set(__self__, "user_group_id", user_group_id)

    @_builtins.property
    @pulumi.getter(name="accountPermissions")
    def account_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The account permissions of the user group. Valid options are ADMINISTER*OTHER*ACCOUNT*FUNCTIONS, CREATE*AND*DELETE*APPLICATION, CREATE*CUSTOM*DASHBOARDS, MANAGE*ALERT*NOTIFICATION*RULES, MANAGE*API*KEYS, MANAGE*APPLICATION*STACKS, MANAGE*AUTHENTICATION*SETTINGS, MANAGE*CLOUD*PROVIDERS, MANAGE*CONFIG*AS*CODE, MANAGE*CONNECTORS, MANAGE*CUSTOM*DASHBOARDS, MANAGE*DELEGATE*PROFILES, MANAGE*DELEGATES, MANAGE*DEPLOYMENT*FREEZES, MANAGE*IP*WHITELIST, MANAGE*PIPELINE*GOVERNANCE*STANDARDS, MANAGE*RESTRICTED*ACCESS, MANAGE*SECRET*MANAGERS, MANAGE*SECRETS, MANAGE*SSH*AND*WINRM, MANAGE*TAGS, MANAGE*TEMPLATE*LIBRARY, MANAGE*USER*AND*USER*GROUPS*AND*API*KEYS, MANAGE*USERS*AND*GROUPS, READ*USERS*AND*GROUPS, VIEW*AUDITS, VIEW*USER*AND*USER*GROUPS*AND*API_KEYS
        """
        return pulumi.get(self, "account_permissions")

    @account_permissions.setter
    def account_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "account_permissions", value)

    @_builtins.property
    @pulumi.getter(name="appPermissions")
    def app_permissions(self) -> Optional[pulumi.Input['UserGroupPermissionsAppPermissionsArgs']]:
        """
        Application specific permissions
        """
        return pulumi.get(self, "app_permissions")

    @app_permissions.setter
    def app_permissions(self, value: Optional[pulumi.Input['UserGroupPermissionsAppPermissionsArgs']]):
        pulumi.set(self, "app_permissions", value)

    @_builtins.property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the user group.
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_group_id", value)


@pulumi.type_token("harness:index/userGroupPermissions:UserGroupPermissions")
class UserGroupPermissions(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 app_permissions: Optional[pulumi.Input[Union['UserGroupPermissionsAppPermissionsArgs', 'UserGroupPermissionsAppPermissionsArgsDict']]] = None,
                 user_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for adding permissions to an existing Harness user group.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] account_permissions: The account permissions of the user group. Valid options are ADMINISTER*OTHER*ACCOUNT*FUNCTIONS, CREATE*AND*DELETE*APPLICATION, CREATE*CUSTOM*DASHBOARDS, MANAGE*ALERT*NOTIFICATION*RULES, MANAGE*API*KEYS, MANAGE*APPLICATION*STACKS, MANAGE*AUTHENTICATION*SETTINGS, MANAGE*CLOUD*PROVIDERS, MANAGE*CONFIG*AS*CODE, MANAGE*CONNECTORS, MANAGE*CUSTOM*DASHBOARDS, MANAGE*DELEGATE*PROFILES, MANAGE*DELEGATES, MANAGE*DEPLOYMENT*FREEZES, MANAGE*IP*WHITELIST, MANAGE*PIPELINE*GOVERNANCE*STANDARDS, MANAGE*RESTRICTED*ACCESS, MANAGE*SECRET*MANAGERS, MANAGE*SECRETS, MANAGE*SSH*AND*WINRM, MANAGE*TAGS, MANAGE*TEMPLATE*LIBRARY, MANAGE*USER*AND*USER*GROUPS*AND*API*KEYS, MANAGE*USERS*AND*GROUPS, READ*USERS*AND*GROUPS, VIEW*AUDITS, VIEW*USER*AND*USER*GROUPS*AND*API_KEYS
        :param pulumi.Input[Union['UserGroupPermissionsAppPermissionsArgs', 'UserGroupPermissionsAppPermissionsArgsDict']] app_permissions: Application specific permissions
        :param pulumi.Input[_builtins.str] user_group_id: Unique identifier of the user group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserGroupPermissionsInitArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for adding permissions to an existing Harness user group.

        :param str resource_name: The name of the resource.
        :param UserGroupPermissionsInitArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserGroupPermissionsInitArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 app_permissions: Optional[pulumi.Input[Union['UserGroupPermissionsAppPermissionsArgs', 'UserGroupPermissionsAppPermissionsArgsDict']]] = None,
                 user_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserGroupPermissionsInitArgs.__new__(UserGroupPermissionsInitArgs)

            __props__.__dict__["account_permissions"] = account_permissions
            __props__.__dict__["app_permissions"] = app_permissions
            if user_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_group_id'")
            __props__.__dict__["user_group_id"] = user_group_id
        super(UserGroupPermissions, __self__).__init__(
            'harness:index/userGroupPermissions:UserGroupPermissions',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            app_permissions: Optional[pulumi.Input[Union['UserGroupPermissionsAppPermissionsArgs', 'UserGroupPermissionsAppPermissionsArgsDict']]] = None,
            user_group_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'UserGroupPermissions':
        """
        Get an existing UserGroupPermissions resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] account_permissions: The account permissions of the user group. Valid options are ADMINISTER*OTHER*ACCOUNT*FUNCTIONS, CREATE*AND*DELETE*APPLICATION, CREATE*CUSTOM*DASHBOARDS, MANAGE*ALERT*NOTIFICATION*RULES, MANAGE*API*KEYS, MANAGE*APPLICATION*STACKS, MANAGE*AUTHENTICATION*SETTINGS, MANAGE*CLOUD*PROVIDERS, MANAGE*CONFIG*AS*CODE, MANAGE*CONNECTORS, MANAGE*CUSTOM*DASHBOARDS, MANAGE*DELEGATE*PROFILES, MANAGE*DELEGATES, MANAGE*DEPLOYMENT*FREEZES, MANAGE*IP*WHITELIST, MANAGE*PIPELINE*GOVERNANCE*STANDARDS, MANAGE*RESTRICTED*ACCESS, MANAGE*SECRET*MANAGERS, MANAGE*SECRETS, MANAGE*SSH*AND*WINRM, MANAGE*TAGS, MANAGE*TEMPLATE*LIBRARY, MANAGE*USER*AND*USER*GROUPS*AND*API*KEYS, MANAGE*USERS*AND*GROUPS, READ*USERS*AND*GROUPS, VIEW*AUDITS, VIEW*USER*AND*USER*GROUPS*AND*API_KEYS
        :param pulumi.Input[Union['UserGroupPermissionsAppPermissionsArgs', 'UserGroupPermissionsAppPermissionsArgsDict']] app_permissions: Application specific permissions
        :param pulumi.Input[_builtins.str] user_group_id: Unique identifier of the user group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserGroupPermissionsState.__new__(_UserGroupPermissionsState)

        __props__.__dict__["account_permissions"] = account_permissions
        __props__.__dict__["app_permissions"] = app_permissions
        __props__.__dict__["user_group_id"] = user_group_id
        return UserGroupPermissions(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountPermissions")
    def account_permissions(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The account permissions of the user group. Valid options are ADMINISTER*OTHER*ACCOUNT*FUNCTIONS, CREATE*AND*DELETE*APPLICATION, CREATE*CUSTOM*DASHBOARDS, MANAGE*ALERT*NOTIFICATION*RULES, MANAGE*API*KEYS, MANAGE*APPLICATION*STACKS, MANAGE*AUTHENTICATION*SETTINGS, MANAGE*CLOUD*PROVIDERS, MANAGE*CONFIG*AS*CODE, MANAGE*CONNECTORS, MANAGE*CUSTOM*DASHBOARDS, MANAGE*DELEGATE*PROFILES, MANAGE*DELEGATES, MANAGE*DEPLOYMENT*FREEZES, MANAGE*IP*WHITELIST, MANAGE*PIPELINE*GOVERNANCE*STANDARDS, MANAGE*RESTRICTED*ACCESS, MANAGE*SECRET*MANAGERS, MANAGE*SECRETS, MANAGE*SSH*AND*WINRM, MANAGE*TAGS, MANAGE*TEMPLATE*LIBRARY, MANAGE*USER*AND*USER*GROUPS*AND*API*KEYS, MANAGE*USERS*AND*GROUPS, READ*USERS*AND*GROUPS, VIEW*AUDITS, VIEW*USER*AND*USER*GROUPS*AND*API_KEYS
        """
        return pulumi.get(self, "account_permissions")

    @_builtins.property
    @pulumi.getter(name="appPermissions")
    def app_permissions(self) -> pulumi.Output[Optional['outputs.UserGroupPermissionsAppPermissions']]:
        """
        Application specific permissions
        """
        return pulumi.get(self, "app_permissions")

    @_builtins.property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the user group.
        """
        return pulumi.get(self, "user_group_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AzureGatewayArgs', 'AzureGateway']

@pulumi.input_type
class AzureGatewayArgs:
    def __init__(__self__, *,
                 azure_func_region: pulumi.Input[_builtins.str],
                 cloud_connector_id: pulumi.Input[_builtins.str],
                 delete_cloud_resources_on_destroy: pulumi.Input[_builtins.bool],
                 host_name: pulumi.Input[_builtins.str],
                 region: pulumi.Input[_builtins.str],
                 resource_group: pulumi.Input[_builtins.str],
                 vpc: pulumi.Input[_builtins.str],
                 app_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 frontend_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 sku_size: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AzureGateway resource.
        :param pulumi.Input[_builtins.str] azure_func_region: Region in which azure cloud function will be provisioned
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[_builtins.str] host_name: Hostname for the proxy
        :param pulumi.Input[_builtins.str] region: Region in which cloud resources are hosted
        :param pulumi.Input[_builtins.str] resource_group: Resource group in which cloud resources are hosted
        :param pulumi.Input[_builtins.str] vpc: VNet in which cloud resources are hosted. Required only for creating new AppGateway
        :param pulumi.Input[_builtins.str] app_gateway_id: ID of Azure AppGateway for importing. Required only for importing exiging AppGateway
        :param pulumi.Input[_builtins.str] certificate_id: ID of existing SSL certificate from AppGateway being imported. Required only for importing existing AppGateway. Required only for SSL based rules
        :param pulumi.Input[_builtins.str] frontend_ip: ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
        :param pulumi.Input[_builtins.str] name: Name of the proxy
        :param pulumi.Input[_builtins.str] sku_size: Size of machine used for the gateway. Required only for creating new AppGateway
        :param pulumi.Input[_builtins.str] subnet_id: Subnet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        pulumi.set(__self__, "azure_func_region", azure_func_region)
        pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        pulumi.set(__self__, "delete_cloud_resources_on_destroy", delete_cloud_resources_on_destroy)
        pulumi.set(__self__, "host_name", host_name)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "resource_group", resource_group)
        pulumi.set(__self__, "vpc", vpc)
        if app_gateway_id is not None:
            pulumi.set(__self__, "app_gateway_id", app_gateway_id)
        if certificate_id is not None:
            pulumi.set(__self__, "certificate_id", certificate_id)
        if frontend_ip is not None:
            pulumi.set(__self__, "frontend_ip", frontend_ip)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if sku_size is not None:
            pulumi.set(__self__, "sku_size", sku_size)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)

    @_builtins.property
    @pulumi.getter(name="azureFuncRegion")
    def azure_func_region(self) -> pulumi.Input[_builtins.str]:
        """
        Region in which azure cloud function will be provisioned
        """
        return pulumi.get(self, "azure_func_region")

    @azure_func_region.setter
    def azure_func_region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "azure_func_region", value)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> pulumi.Input[_builtins.str]:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @cloud_connector_id.setter
    def cloud_connector_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cloud_connector_id", value)

    @_builtins.property
    @pulumi.getter(name="deleteCloudResourcesOnDestroy")
    def delete_cloud_resources_on_destroy(self) -> pulumi.Input[_builtins.bool]:
        return pulumi.get(self, "delete_cloud_resources_on_destroy")

    @delete_cloud_resources_on_destroy.setter
    def delete_cloud_resources_on_destroy(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "delete_cloud_resources_on_destroy", value)

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Input[_builtins.str]:
        """
        Hostname for the proxy
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "host_name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Input[_builtins.str]:
        """
        Region in which cloud resources are hosted
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroup")
    def resource_group(self) -> pulumi.Input[_builtins.str]:
        """
        Resource group in which cloud resources are hosted
        """
        return pulumi.get(self, "resource_group")

    @resource_group.setter
    def resource_group(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group", value)

    @_builtins.property
    @pulumi.getter
    def vpc(self) -> pulumi.Input[_builtins.str]:
        """
        VNet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        return pulumi.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "vpc", value)

    @_builtins.property
    @pulumi.getter(name="appGatewayId")
    def app_gateway_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of Azure AppGateway for importing. Required only for importing exiging AppGateway
        """
        return pulumi.get(self, "app_gateway_id")

    @app_gateway_id.setter
    def app_gateway_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_gateway_id", value)

    @_builtins.property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of existing SSL certificate from AppGateway being imported. Required only for importing existing AppGateway. Required only for SSL based rules
        """
        return pulumi.get(self, "certificate_id")

    @certificate_id.setter
    def certificate_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate_id", value)

    @_builtins.property
    @pulumi.getter(name="frontendIp")
    def frontend_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
        """
        return pulumi.get(self, "frontend_ip")

    @frontend_ip.setter
    def frontend_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "frontend_ip", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the proxy
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="skuSize")
    def sku_size(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Size of machine used for the gateway. Required only for creating new AppGateway
        """
        return pulumi.get(self, "sku_size")

    @sku_size.setter
    def sku_size(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sku_size", value)

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Subnet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subnet_id", value)


@pulumi.input_type
class _AzureGatewayState:
    def __init__(__self__, *,
                 app_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 azure_func_region: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delete_cloud_resources_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 frontend_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group: Optional[pulumi.Input[_builtins.str]] = None,
                 sku_size: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AzureGateway resources.
        :param pulumi.Input[_builtins.str] app_gateway_id: ID of Azure AppGateway for importing. Required only for importing exiging AppGateway
        :param pulumi.Input[_builtins.str] azure_func_region: Region in which azure cloud function will be provisioned
        :param pulumi.Input[_builtins.str] certificate_id: ID of existing SSL certificate from AppGateway being imported. Required only for importing existing AppGateway. Required only for SSL based rules
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[_builtins.str] frontend_ip: ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
        :param pulumi.Input[_builtins.str] host_name: Hostname for the proxy
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.str] name: Name of the proxy
        :param pulumi.Input[_builtins.str] region: Region in which cloud resources are hosted
        :param pulumi.Input[_builtins.str] resource_group: Resource group in which cloud resources are hosted
        :param pulumi.Input[_builtins.str] sku_size: Size of machine used for the gateway. Required only for creating new AppGateway
        :param pulumi.Input[_builtins.str] subnet_id: Subnet in which cloud resources are hosted. Required only for creating new AppGateway
        :param pulumi.Input[_builtins.str] vpc: VNet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        if app_gateway_id is not None:
            pulumi.set(__self__, "app_gateway_id", app_gateway_id)
        if azure_func_region is not None:
            pulumi.set(__self__, "azure_func_region", azure_func_region)
        if certificate_id is not None:
            pulumi.set(__self__, "certificate_id", certificate_id)
        if cloud_connector_id is not None:
            pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        if delete_cloud_resources_on_destroy is not None:
            pulumi.set(__self__, "delete_cloud_resources_on_destroy", delete_cloud_resources_on_destroy)
        if frontend_ip is not None:
            pulumi.set(__self__, "frontend_ip", frontend_ip)
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if resource_group is not None:
            pulumi.set(__self__, "resource_group", resource_group)
        if sku_size is not None:
            pulumi.set(__self__, "sku_size", sku_size)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)

    @_builtins.property
    @pulumi.getter(name="appGatewayId")
    def app_gateway_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of Azure AppGateway for importing. Required only for importing exiging AppGateway
        """
        return pulumi.get(self, "app_gateway_id")

    @app_gateway_id.setter
    def app_gateway_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_gateway_id", value)

    @_builtins.property
    @pulumi.getter(name="azureFuncRegion")
    def azure_func_region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region in which azure cloud function will be provisioned
        """
        return pulumi.get(self, "azure_func_region")

    @azure_func_region.setter
    def azure_func_region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "azure_func_region", value)

    @_builtins.property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of existing SSL certificate from AppGateway being imported. Required only for importing existing AppGateway. Required only for SSL based rules
        """
        return pulumi.get(self, "certificate_id")

    @certificate_id.setter
    def certificate_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate_id", value)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @cloud_connector_id.setter
    def cloud_connector_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud_connector_id", value)

    @_builtins.property
    @pulumi.getter(name="deleteCloudResourcesOnDestroy")
    def delete_cloud_resources_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "delete_cloud_resources_on_destroy")

    @delete_cloud_resources_on_destroy.setter
    def delete_cloud_resources_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "delete_cloud_resources_on_destroy", value)

    @_builtins.property
    @pulumi.getter(name="frontendIp")
    def frontend_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
        """
        return pulumi.get(self, "frontend_ip")

    @frontend_ip.setter
    def frontend_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "frontend_ip", value)

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname for the proxy
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "host_name", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the proxy
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region in which cloud resources are hosted
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroup")
    def resource_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Resource group in which cloud resources are hosted
        """
        return pulumi.get(self, "resource_group")

    @resource_group.setter
    def resource_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group", value)

    @_builtins.property
    @pulumi.getter(name="skuSize")
    def sku_size(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Size of machine used for the gateway. Required only for creating new AppGateway
        """
        return pulumi.get(self, "sku_size")

    @sku_size.setter
    def sku_size(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sku_size", value)

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Subnet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @_builtins.property
    @pulumi.getter
    def vpc(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        VNet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        return pulumi.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpc", value)


@pulumi.type_token("harness:autostopping/azureGateway:AzureGateway")
class AzureGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 azure_func_region: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delete_cloud_resources_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 frontend_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group: Optional[pulumi.Input[_builtins.str]] = None,
                 sku_size: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating an Azure Application Gateway

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.autostopping.AzureGateway("test",
            name="name",
            cloud_connector_id="cloud_connector_id",
            host_name="host_name",
            region="eastus2",
            resource_group="resource_group",
            subnet_id="/subscriptions/subscription_id/resourceGroups/resource_group/providers/Microsoft.Network/virtualNetworks/virtual_network/subnets/subnet_id",
            vpc="/subscriptions/subscription_id/resourceGroups/resource_group/providers/Microsoft.Network/virtualNetworks/virtual_network",
            azure_func_region="westus2",
            frontend_ip="/subscriptions/subscription_id/resourceGroups/resource_group/providers/Microsoft.Network/publicIPAddresses/publicip",
            sku_size="sku2",
            delete_cloud_resources_on_destroy=True)
        import_test = harness.autostopping.AzureGateway("import_test",
            name="import_test",
            cloud_connector_id="cloud_connector_id",
            host_name="host_name",
            region="westus2",
            resource_group="test_resource_group",
            app_gateway_id="/subscriptions/subscription_id/resourceGroups/test_resource_group/providers/Microsoft.Network/applicationGateways/TestAppGateway",
            certificate_id="/subscriptions/subscription_id/resourceGroups/test_resource_group/providers/Microsoft.Network/applicationGateways/TestAppGateway/sslCertificates/certificate_name",
            azure_func_region="westus2",
            vpc="/subscriptions/subscription_id/resourceGroups/test_resource_group/providers/Microsoft.Network/virtualNetworks/test_resource_group_vnet",
            delete_cloud_resources_on_destroy=False)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_gateway_id: ID of Azure AppGateway for importing. Required only for importing exiging AppGateway
        :param pulumi.Input[_builtins.str] azure_func_region: Region in which azure cloud function will be provisioned
        :param pulumi.Input[_builtins.str] certificate_id: ID of existing SSL certificate from AppGateway being imported. Required only for importing existing AppGateway. Required only for SSL based rules
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[_builtins.str] frontend_ip: ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
        :param pulumi.Input[_builtins.str] host_name: Hostname for the proxy
        :param pulumi.Input[_builtins.str] name: Name of the proxy
        :param pulumi.Input[_builtins.str] region: Region in which cloud resources are hosted
        :param pulumi.Input[_builtins.str] resource_group: Resource group in which cloud resources are hosted
        :param pulumi.Input[_builtins.str] sku_size: Size of machine used for the gateway. Required only for creating new AppGateway
        :param pulumi.Input[_builtins.str] subnet_id: Subnet in which cloud resources are hosted. Required only for creating new AppGateway
        :param pulumi.Input[_builtins.str] vpc: VNet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AzureGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an Azure Application Gateway

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.autostopping.AzureGateway("test",
            name="name",
            cloud_connector_id="cloud_connector_id",
            host_name="host_name",
            region="eastus2",
            resource_group="resource_group",
            subnet_id="/subscriptions/subscription_id/resourceGroups/resource_group/providers/Microsoft.Network/virtualNetworks/virtual_network/subnets/subnet_id",
            vpc="/subscriptions/subscription_id/resourceGroups/resource_group/providers/Microsoft.Network/virtualNetworks/virtual_network",
            azure_func_region="westus2",
            frontend_ip="/subscriptions/subscription_id/resourceGroups/resource_group/providers/Microsoft.Network/publicIPAddresses/publicip",
            sku_size="sku2",
            delete_cloud_resources_on_destroy=True)
        import_test = harness.autostopping.AzureGateway("import_test",
            name="import_test",
            cloud_connector_id="cloud_connector_id",
            host_name="host_name",
            region="westus2",
            resource_group="test_resource_group",
            app_gateway_id="/subscriptions/subscription_id/resourceGroups/test_resource_group/providers/Microsoft.Network/applicationGateways/TestAppGateway",
            certificate_id="/subscriptions/subscription_id/resourceGroups/test_resource_group/providers/Microsoft.Network/applicationGateways/TestAppGateway/sslCertificates/certificate_name",
            azure_func_region="westus2",
            vpc="/subscriptions/subscription_id/resourceGroups/test_resource_group/providers/Microsoft.Network/virtualNetworks/test_resource_group_vnet",
            delete_cloud_resources_on_destroy=False)
        ```

        :param str resource_name: The name of the resource.
        :param AzureGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AzureGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
                 azure_func_region: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delete_cloud_resources_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 frontend_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group: Optional[pulumi.Input[_builtins.str]] = None,
                 sku_size: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vpc: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AzureGatewayArgs.__new__(AzureGatewayArgs)

            __props__.__dict__["app_gateway_id"] = app_gateway_id
            if azure_func_region is None and not opts.urn:
                raise TypeError("Missing required property 'azure_func_region'")
            __props__.__dict__["azure_func_region"] = azure_func_region
            __props__.__dict__["certificate_id"] = certificate_id
            if cloud_connector_id is None and not opts.urn:
                raise TypeError("Missing required property 'cloud_connector_id'")
            __props__.__dict__["cloud_connector_id"] = cloud_connector_id
            if delete_cloud_resources_on_destroy is None and not opts.urn:
                raise TypeError("Missing required property 'delete_cloud_resources_on_destroy'")
            __props__.__dict__["delete_cloud_resources_on_destroy"] = delete_cloud_resources_on_destroy
            __props__.__dict__["frontend_ip"] = frontend_ip
            if host_name is None and not opts.urn:
                raise TypeError("Missing required property 'host_name'")
            __props__.__dict__["host_name"] = host_name
            __props__.__dict__["name"] = name
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            if resource_group is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group'")
            __props__.__dict__["resource_group"] = resource_group
            __props__.__dict__["sku_size"] = sku_size
            __props__.__dict__["subnet_id"] = subnet_id
            if vpc is None and not opts.urn:
                raise TypeError("Missing required property 'vpc'")
            __props__.__dict__["vpc"] = vpc
            __props__.__dict__["identifier"] = None
        super(AzureGateway, __self__).__init__(
            'harness:autostopping/azureGateway:AzureGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_gateway_id: Optional[pulumi.Input[_builtins.str]] = None,
            azure_func_region: Optional[pulumi.Input[_builtins.str]] = None,
            certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
            cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
            delete_cloud_resources_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            frontend_ip: Optional[pulumi.Input[_builtins.str]] = None,
            host_name: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            resource_group: Optional[pulumi.Input[_builtins.str]] = None,
            sku_size: Optional[pulumi.Input[_builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
            vpc: Optional[pulumi.Input[_builtins.str]] = None) -> 'AzureGateway':
        """
        Get an existing AzureGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_gateway_id: ID of Azure AppGateway for importing. Required only for importing exiging AppGateway
        :param pulumi.Input[_builtins.str] azure_func_region: Region in which azure cloud function will be provisioned
        :param pulumi.Input[_builtins.str] certificate_id: ID of existing SSL certificate from AppGateway being imported. Required only for importing existing AppGateway. Required only for SSL based rules
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[_builtins.str] frontend_ip: ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
        :param pulumi.Input[_builtins.str] host_name: Hostname for the proxy
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.str] name: Name of the proxy
        :param pulumi.Input[_builtins.str] region: Region in which cloud resources are hosted
        :param pulumi.Input[_builtins.str] resource_group: Resource group in which cloud resources are hosted
        :param pulumi.Input[_builtins.str] sku_size: Size of machine used for the gateway. Required only for creating new AppGateway
        :param pulumi.Input[_builtins.str] subnet_id: Subnet in which cloud resources are hosted. Required only for creating new AppGateway
        :param pulumi.Input[_builtins.str] vpc: VNet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AzureGatewayState.__new__(_AzureGatewayState)

        __props__.__dict__["app_gateway_id"] = app_gateway_id
        __props__.__dict__["azure_func_region"] = azure_func_region
        __props__.__dict__["certificate_id"] = certificate_id
        __props__.__dict__["cloud_connector_id"] = cloud_connector_id
        __props__.__dict__["delete_cloud_resources_on_destroy"] = delete_cloud_resources_on_destroy
        __props__.__dict__["frontend_ip"] = frontend_ip
        __props__.__dict__["host_name"] = host_name
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["resource_group"] = resource_group
        __props__.__dict__["sku_size"] = sku_size
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["vpc"] = vpc
        return AzureGateway(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appGatewayId")
    def app_gateway_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of Azure AppGateway for importing. Required only for importing exiging AppGateway
        """
        return pulumi.get(self, "app_gateway_id")

    @_builtins.property
    @pulumi.getter(name="azureFuncRegion")
    def azure_func_region(self) -> pulumi.Output[_builtins.str]:
        """
        Region in which azure cloud function will be provisioned
        """
        return pulumi.get(self, "azure_func_region")

    @_builtins.property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of existing SSL certificate from AppGateway being imported. Required only for importing existing AppGateway. Required only for SSL based rules
        """
        return pulumi.get(self, "certificate_id")

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> pulumi.Output[_builtins.str]:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @_builtins.property
    @pulumi.getter(name="deleteCloudResourcesOnDestroy")
    def delete_cloud_resources_on_destroy(self) -> pulumi.Output[_builtins.bool]:
        return pulumi.get(self, "delete_cloud_resources_on_destroy")

    @_builtins.property
    @pulumi.getter(name="frontendIp")
    def frontend_ip(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
        """
        return pulumi.get(self, "frontend_ip")

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Output[_builtins.str]:
        """
        Hostname for the proxy
        """
        return pulumi.get(self, "host_name")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the proxy
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        Region in which cloud resources are hosted
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="resourceGroup")
    def resource_group(self) -> pulumi.Output[_builtins.str]:
        """
        Resource group in which cloud resources are hosted
        """
        return pulumi.get(self, "resource_group")

    @_builtins.property
    @pulumi.getter(name="skuSize")
    def sku_size(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Size of machine used for the gateway. Required only for creating new AppGateway
        """
        return pulumi.get(self, "sku_size")

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Subnet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        return pulumi.get(self, "subnet_id")

    @_builtins.property
    @pulumi.getter
    def vpc(self) -> pulumi.Output[_builtins.str]:
        """
        VNet in which cloud resources are hosted. Required only for creating new AppGateway
        """
        return pulumi.get(self, "vpc")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRepoResult',
    'AwaitableGetRepoResult',
    'get_repo',
    'get_repo_output',
]

@pulumi.output_type
class GetRepoResult:
    """
    A collection of values returned by getRepo.
    """
    def __init__(__self__, created=None, created_by=None, default_branch=None, description=None, git_ignore=None, git_url=None, id=None, identifier=None, license=None, name=None, org_id=None, path=None, project_id=None, readme=None, sources=None, updated=None):
        if created and not isinstance(created, int):
            raise TypeError("Expected argument 'created' to be a int")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, int):
            raise TypeError("Expected argument 'created_by' to be a int")
        pulumi.set(__self__, "created_by", created_by)
        if default_branch and not isinstance(default_branch, str):
            raise TypeError("Expected argument 'default_branch' to be a str")
        pulumi.set(__self__, "default_branch", default_branch)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if git_ignore and not isinstance(git_ignore, str):
            raise TypeError("Expected argument 'git_ignore' to be a str")
        pulumi.set(__self__, "git_ignore", git_ignore)
        if git_url and not isinstance(git_url, str):
            raise TypeError("Expected argument 'git_url' to be a str")
        pulumi.set(__self__, "git_url", git_url)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if license and not isinstance(license, str):
            raise TypeError("Expected argument 'license' to be a str")
        pulumi.set(__self__, "license", license)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if readme and not isinstance(readme, bool):
            raise TypeError("Expected argument 'readme' to be a bool")
        pulumi.set(__self__, "readme", readme)
        if sources and not isinstance(sources, list):
            raise TypeError("Expected argument 'sources' to be a list")
        pulumi.set(__self__, "sources", sources)
        if updated and not isinstance(updated, int):
            raise TypeError("Expected argument 'updated' to be a int")
        pulumi.set(__self__, "updated", updated)

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.int:
        """
        Timestamp when the repository was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.int:
        """
        ID of the user who created the repository.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="defaultBranch")
    def default_branch(self) -> Optional[_builtins.str]:
        """
        Default branch of the repository (Applicate only for create).
        """
        return pulumi.get(self, "default_branch")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Description of the repository.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitIgnore")
    def git_ignore(self) -> Optional[_builtins.str]:
        """
        Repository should be created with specified predefined gitignore file.
        """
        return pulumi.get(self, "git_ignore")

    @_builtins.property
    @pulumi.getter(name="gitUrl")
    def git_url(self) -> _builtins.str:
        """
        Git URL of the repository.
        """
        return pulumi.get(self, "git_url")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Internal ID of the repository.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the repository.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def license(self) -> Optional[_builtins.str]:
        """
        Repository should be created with specified predefined license file.
        """
        return pulumi.get(self, "license")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the repository.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def path(self) -> _builtins.str:
        """
        Path of the repository.
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def readme(self) -> Optional[_builtins.bool]:
        """
        Repository should be created with readme file.
        """
        return pulumi.get(self, "readme")

    @_builtins.property
    @pulumi.getter
    def sources(self) -> Optional[Sequence['outputs.GetRepoSourceResult']]:
        """
        Configuration for importing an existing repository from SCM provider.
        """
        return pulumi.get(self, "sources")

    @_builtins.property
    @pulumi.getter
    def updated(self) -> _builtins.int:
        """
        Timestamp when the repository was last updated.
        """
        return pulumi.get(self, "updated")


class AwaitableGetRepoResult(GetRepoResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepoResult(
            created=self.created,
            created_by=self.created_by,
            default_branch=self.default_branch,
            description=self.description,
            git_ignore=self.git_ignore,
            git_url=self.git_url,
            id=self.id,
            identifier=self.identifier,
            license=self.license,
            name=self.name,
            org_id=self.org_id,
            path=self.path,
            project_id=self.project_id,
            readme=self.readme,
            sources=self.sources,
            updated=self.updated)


def get_repo(default_branch: Optional[_builtins.str] = None,
             description: Optional[_builtins.str] = None,
             git_ignore: Optional[_builtins.str] = None,
             identifier: Optional[_builtins.str] = None,
             license: Optional[_builtins.str] = None,
             org_id: Optional[_builtins.str] = None,
             project_id: Optional[_builtins.str] = None,
             readme: Optional[_builtins.bool] = None,
             sources: Optional[Sequence[Union['GetRepoSourceArgs', 'GetRepoSourceArgsDict']]] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepoResult:
    """
    Data source for retrieving a Harness repo.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example_by_identifier = harness.platform.get_repo(identifier="identifier",
        org_id="org_id",
        project_id="proj_id")
    ```


    :param _builtins.str default_branch: Default branch of the repository (Applicate only for create).
    :param _builtins.str description: Description of the repository.
    :param _builtins.str git_ignore: Repository should be created with specified predefined gitignore file.
    :param _builtins.str identifier: Identifier of the repository.
    :param _builtins.str license: Repository should be created with specified predefined license file.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.bool readme: Repository should be created with readme file.
    :param Sequence[Union['GetRepoSourceArgs', 'GetRepoSourceArgsDict']] sources: Configuration for importing an existing repository from SCM provider.
    """
    __args__ = dict()
    __args__['defaultBranch'] = default_branch
    __args__['description'] = description
    __args__['gitIgnore'] = git_ignore
    __args__['identifier'] = identifier
    __args__['license'] = license
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['readme'] = readme
    __args__['sources'] = sources
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getRepo:getRepo', __args__, opts=opts, typ=GetRepoResult).value

    return AwaitableGetRepoResult(
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        default_branch=pulumi.get(__ret__, 'default_branch'),
        description=pulumi.get(__ret__, 'description'),
        git_ignore=pulumi.get(__ret__, 'git_ignore'),
        git_url=pulumi.get(__ret__, 'git_url'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        license=pulumi.get(__ret__, 'license'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        path=pulumi.get(__ret__, 'path'),
        project_id=pulumi.get(__ret__, 'project_id'),
        readme=pulumi.get(__ret__, 'readme'),
        sources=pulumi.get(__ret__, 'sources'),
        updated=pulumi.get(__ret__, 'updated'))
def get_repo_output(default_branch: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    git_ignore: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    identifier: Optional[pulumi.Input[_builtins.str]] = None,
                    license: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    readme: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                    sources: Optional[pulumi.Input[Optional[Sequence[Union['GetRepoSourceArgs', 'GetRepoSourceArgsDict']]]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRepoResult]:
    """
    Data source for retrieving a Harness repo.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example_by_identifier = harness.platform.get_repo(identifier="identifier",
        org_id="org_id",
        project_id="proj_id")
    ```


    :param _builtins.str default_branch: Default branch of the repository (Applicate only for create).
    :param _builtins.str description: Description of the repository.
    :param _builtins.str git_ignore: Repository should be created with specified predefined gitignore file.
    :param _builtins.str identifier: Identifier of the repository.
    :param _builtins.str license: Repository should be created with specified predefined license file.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.bool readme: Repository should be created with readme file.
    :param Sequence[Union['GetRepoSourceArgs', 'GetRepoSourceArgsDict']] sources: Configuration for importing an existing repository from SCM provider.
    """
    __args__ = dict()
    __args__['defaultBranch'] = default_branch
    __args__['description'] = description
    __args__['gitIgnore'] = git_ignore
    __args__['identifier'] = identifier
    __args__['license'] = license
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['readme'] = readme
    __args__['sources'] = sources
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getRepo:getRepo', __args__, opts=opts, typ=GetRepoResult)
    return __ret__.apply(lambda __response__: GetRepoResult(
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        default_branch=pulumi.get(__response__, 'default_branch'),
        description=pulumi.get(__response__, 'description'),
        git_ignore=pulumi.get(__response__, 'git_ignore'),
        git_url=pulumi.get(__response__, 'git_url'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        license=pulumi.get(__response__, 'license'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        path=pulumi.get(__response__, 'path'),
        project_id=pulumi.get(__response__, 'project_id'),
        readme=pulumi.get(__response__, 'readme'),
        sources=pulumi.get(__response__, 'sources'),
        updated=pulumi.get(__response__, 'updated')))
